# uv Up Tool

uv tool to upgrade all dependencies

[![PyPI](https://img.shields.io/pypi/v/uv-up)](https://pypi.org/project/uv-up/)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/uv-up)](https://pypi.org/project/uv-up/)

[![Downloads](https://static.pepy.tech/badge/uv-up)](https://pepy.tech/project/uv-up)
[![GitLab stars](https://img.shields.io/gitlab/stars/rocshers/python/uv-up)](https://gitlab.com/rocshers/python/uv-up)
[![GitLab last commit](https://img.shields.io/gitlab/last-commit/rocshers/python/uv-up)](https://gitlab.com/rocshers/python/uv-up)

## Functionality

- Upgrade all dependencies to the latest version

## Quick start

```bash
uvx uv-up --latest
```

## Contribute

Issue Tracker: <https://gitlab.com/rocshers/python/uv-up/-/issues>  
Source Code: <https://gitlab.com/rocshers/python/uv-up>

Before adding changes:

```bash
make install
```

After changes:

```bash
make format test
```
